Use Cases and Special Workflows
===============================

Explore specific examples and workflows for using MimiqCircuits.

.. grid:: 1 2 2 3
    :gutter: 3

    .. grid-item-card:: :octicon:`beaker` VQE
        :link: vqe
        :link-type: doc

        Variational Quantum Eigensolver example.

    .. grid-item-card:: :octicon:`check-circle` Circuit Tester
        :link: circuit_tester
        :link-type: doc

        Methodologies for automating equivalence testing.

    .. grid-item-card:: :octicon:`graph` QFT Demo
        :link: https://qperfect.io/index.php/2025/02/11/mimiq-demo-quantum-fourier-transform/
        :link-type: url

        Quantum Fourier Transform demo on QPerfect.io.

    .. grid-item-card:: :octicon:`search` Grover Demo
        :link: https://qperfect.io/index.php/2025/02/04/demo-grover/
        :link-type: url

        Grover's Algorithm demo on QPerfect.io.

    .. grid-item-card:: :octicon:`pulse` KPZ Dynamics
        :link: https://qperfect.io/index.php/2025/01/31/demo-kpz/
        :link-type: url

        Kardar-Parisi-Zhang (KPZ) dynamics demo on QPerfect.io.

    .. grid-item-card:: :octicon:`package` Quantum Volume
        :link: https://qperfect.io/index.php/2025/02/05/mimiq-demo-qv/
        :link-type: url

        Quantum Volume (QV) benchmark demo on QPerfect.io.

    .. grid-item-card:: :octicon:`shield` Surface Code
        :link: https://qperfect.io/index.php/2025/02/10/mimiq-demo-surface-code/
        :link-type: url

        Surface Code simulation demo on QPerfect.io.

    .. grid-item-card:: :octicon:`hubot` GHZ State
        :link: https://qperfect.io/index.php/2025/02/15/mimiq-demo-ghz-state/
        :link-type: url

        GHZ State preparation demo on QPerfect.io.

.. toctree::
    :hidden:

    vqe
    circuit_tester
